{% extends "admin/change_form.html" %}

{% block form_top %}
  {% if not is_popup %}
    <p>{{ _("First, enter a username and password. Then, you'll be able to edit more user options.") }}</p>
  {% else %}
    <p>{{ _("Enter a username and password.") }}</p>
  {% endif %}
{% endblock %}

{% block after_field_sets %}
<script type="text/javascript">document.getElementById("id_username").focus();</script>
{% endblock %}