{% extends "admin/base_site.html" %}

{% block extrahead %}{{ super() }}
{% set jsi18nurl=url('admin:jsi18n') %}
<script type="text/javascript" src="{{ jsi18nurl|default("../../../../jsi18n/") }}"></script>
{% endblock %}
{% block extrastyle %}{{ super() }}<link rel="stylesheet" type="text/css" href="{{ admin_media_prefix }}css/forms.css" />{% endblock %}
{% block bodyclass %}{{ opts.app_label }}-{{ opts.object_name.lower }} change-form{% endblock %}
{% block breadcrumbs %}{% if not is_popup %}
<div class="breadcrumbs">
     <a href="../../../../">{{ _("Home") }}</a> &rsaquo;
     <a href="../../../">{{ opts.app_label|capitalize|escape }}</a> &rsaquo;
     <a href="../../">{{ opts.verbose_name_plural|capitalize }}</a> &rsaquo;
     <a href="../">{{ original|truncatewords(18) }}</a> &rsaquo;
     {{ _('Change password') }}
</div>
{% endif %}{% endblock %}
{% block content %}<div id="content-main">
<form action="{{ form_url }}" method="post" id="{{ opts.module_name }}_form">{% csrf_token %}{% block form_top %}{% endblock %}
<div>
{% if is_popup %}<input type="hidden" name="_popup" value="1" />{% endif %}
{% if form.errors %}
    <p class="errornote">
    {% trans count=form.errors.items|length %}Please correct the error below.{% pluralize %}Please correct the errors below.{% endtrans %}
    </p>
{% endif %}

<p>{% trans username=original.username %}Enter a new password for the user <strong>{{ username }}</strong>.{% endtrans %}</p>

<fieldset class="module aligned">

<div class="form-row">
  {{ form.password1.errors }}
  {# TODO: get required class on label_tag #}
  <label for="id_password1" class="required">{{ _('Password') }}:</label> {{ form.password1 }}
</div>

<div class="form-row">
  {{ form.password2.errors }}
  {# TODO: get required class on label_tag #}
  <label for="id_password2" class="required">{{ _('Password (again)') }}:</label> {{ form.password2 }}
  <p class="help">{{ _('Enter the same password as above, for verification.') }}</p>
</div>

</fieldset>

<div class="submit-row">
<input type="submit" value="{{ _('Change password') }}" class="default" />
</div>

<script type="text/javascript">document.getElementById("id_password1").focus();</script>
</div>
</form></div>
{% endblock %}