<div class="djDebugPanelTitle">
	<a class="djDebugClose djDebugBack" href="">{{ _("Back") }}</a>
	<h3>{{ _("SQL Selected") }}</h3>
</div>
<div class="djDebugPanelContent">
	<div class="scroll">
		<dl>
			<dt>{{ _("Executed SQL") }}</dt>
			<dd>{{ sql|safe }}</dd>
			<dt>{{ _("Time") }}</dt>
			<dd>{{ duration }} ms</dd>
		</dl>
		{% if result %}
		<table class="djSqlSelect">
			<thead>
				<tr>
					{% for h in headers %}
						<th>{{ h|upper }}</th>
					{% endfor %}
				</tr>
			</thead>
			<tbody>
				{% for row in result %}
					<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
						{% for column in row %}
							<td>{{ column|escape }}</td>
						{% endfor %}
					</tr>
				{% endfor %}
			</tbody>
		</table>
		{% else %}
			<p>{{ _("Empty set") }}</p>
		{% endif %}
	</div>
</div>
