{% extends "admin/base_site.html" %}

{% block title %}{{ _('Page not found') }}{% endblock %}

{% block content %}

<h2>{{ _('Page not found') }</h2>

<p>{{ _("We're sorry, but the requested page could not be found.") }}</p>

{% endblock %}