<table>
	<thead>
		<tr>
			<th>{{ _("Key") }}</th>
			<th>{{ _("Value") }}</th>
		</tr>
	</thead>
	<tbody>
		{% for key, value in headers.iteritems() %}
			<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
				<td>{{ key|escape }}</td>
				<td>{{ value|escape }}</td>
			</tr>
		{% endfor %}
	</tbody>
</table>