{% extends "admin/index.html" %} 

{% if not is_popup %}

{% block breadcrumbs %}
<div class="breadcrumbs"><a href="../">
{{ _("Home") }}</a> &rsaquo; 
{% for app in app_list %}
{% trans name=app.name %}{{ name }}{% endtrans %}
{% endfor %}</div>{% endblock %}

{% endif %} 

{% block sidebar %}{% endblock %}