{% extends "admin/base_site.html" %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../">{{ _('Home') }}</a> &rsaquo; {{ _('Password reset') }}</div>{% endblock %}

{% block title %}{{ _('Password reset complete') }}{% endblock %}

{% block content %}

<h1>{{ _('Password reset complete') }}</h1>

<p>{{ _("Your password has been set.  You may go ahead and log in now.") }}</p>

<p><a href="{{ login_url }}">{{ _('Log in') }}</a></p>

{% endblock %}
