<h4>{{ _('Template path') }}{{ template_dirs|length|pluralize }}</h4>
{% if template_dirs %}
	<ol>
	{% for template in template_dirs %}
		<li>{{ template }}</li>
	{% endfor %}
	</ol>
{% else %}
	<p>None</p>
{% endif %}

<h4>{{ _("Template") }}{{ templates|length|pluralize }}</h4>
{% if templates %}
<dl>
{% for template in templates %}
	<dt><strong><a class="remoteCall toggleTemplate" href="/__debug__/template_source/?template={{ template.template.name }}">{{ template.template.name|addslashes }}</a></strong></dt>
	<dd><samp>{{ template.template.origin_name|addslashes }}</samp></dd>
	{% if template.context %}
	<dd>
		<div class="djTemplateShowContextDiv"><a class="djTemplateShowContext"><span class="toggleArrow">&#x25B6;</span> {{ _('Toggle Context') }}</a></div>
		<div class="djTemplateHideContextDiv" style="display:none;"><code>{{ template.context }}</code></div>
	</dd>
	{% endif %}
{% endfor %}
</dl>
{% else %}
	<p>{{ _('None') }}</p>
{% endif %}

<h4>{{ _('Context processor') }}{{ context_processors|length|pluralize }}</h4>
{% if context_processors %}
<dl>
{% for key, value in context_processors.iteritems() %}
	<dt><strong>{{ key|escape }}</strong></dt>
	<dd>
		<div class="djTemplateShowContextDiv"><a class="djTemplateShowContext"><span class="toggleArrow">&#x25B6;</span> {{ _('Toggle Context') }}</a></div>
		<div class="djTemplateHideContextDiv" style="display:none;"><code>{{ value|escape }}</code></div>
	</dd>
{% endfor %}
</dl>
{% else %}
	<p>{{ _('None') }}</p>
{% endif %}