{% extends "admin/base_site.html" %}

{% block userlinks %}{% set docsroot = url('django-admindocs-docroot') %}{% if docsroot %}<a href="{{ docsroot }}">{{ _('Documentation') }}</a> / {% endif %}{{ _('Change password') }} / <a href="../../logout/">{{ _('Log out') }}</a>{% endblock %}
{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../">{{ _('Home') }}</a> &rsaquo; {{ _('Password change') }}</div>{% endblock %}

{% block title %}{{ _('Password change successful') }}{% endblock %}

{% block content %}

<h1>{{ _('Password change successful') }}</h1>

<p>{{ _('Your password was changed.') }}</p>

{% endblock %}